app

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(cfg Config) error

Run is the main entrypoint for the application logic.

Types

type Config

type Config struct {
	Debug            bool
	GithubToken      string
	OutputDir        string
	OverrideParams   []string
	OverrideTargets  []string
	OverrideTemplate string
	SpecFile         string
	ValidationFile   string
	IsSpecFile       bool
}

Config holds all configuration flags passed from the CLI

Jump to